\name{CoCoOldData-internal}
\title{Internal CoCoOldData objects}
\alias{.clear.coco.objects}
\alias{.First.lib}
\alias{.new.coco}
\alias{.new.coco.model}
\alias{.object.of.model}
\alias{.object.of.thing}
\alias{.onLoad}
\alias{.recover.model}
\alias{.recover.reference}
\alias{.return.key}
\alias{.return.model.number}
\alias{.return.model.of.object}
\alias{.return.object.model.number}
\alias{.return.reference}
\alias{.return.type}
\alias{.set.asymptotic}
\alias{.set.coco.value}
\alias{.set.em.epsilon}
\alias{.set.em.initial}
\alias{.set.em.max.iterations}
\alias{.set.exact.epsilon}
\alias{.set.exact.test}
\alias{.set.ips.epsilon}
\alias{.set.ips.max.iterations}
\alias{.set.ips.stop.criterion}
\alias{.set.list.of.number.of.tables}
\alias{.set.number.of.tables}
\alias{.set.page.formats}
\alias{.set.paging.length}
\alias{.set.power.lambda}
\alias{.set.print.formats}
\alias{.set.seed.coco}
\alias{.SetSlotValue}
\alias{.set.table.formats}
\alias{.set.test}
\alias{.set.test.formats}

\alias{label} % CoCoTestClass-method
\alias{testLabel} % CoCoTestClass-method
\alias{width} % CoCoTestClass-method
\alias{testWidth} % CoCoTestClass-method

\alias{dynamic.Graph} % CoCoModelClass-method
\alias{dynamic.Graph.Old} % CoCoModelClass-method
\alias{modifyModel} % CoCoModelClass-method
\alias{subModifyModel} % CoCoModelClass-method
\alias{subModifyModel.Old} % CoCoModelClass-method
\alias{testEdge} % CoCoModelClass-method
\alias{testEdge.Old} % CoCoModelClass-method

\alias{makeModel} % CoCoObjects
\alias{newCoCoTestObject} % CoCoObjects
\alias{recover.coco.model} % CoCoObjects

\alias{coco.init} % From CoCoCore
\alias{coco.resume} % From CoCoCore
\alias{coco.start} % From CoCoCore
\alias{currentCoCo} % From CoCoObjects
\alias{endCoCo} % From CoCoRaw
\alias{is.number} % From CoCoCore
\alias{make.cococg} % From CoCoCore
\alias{make.coco} % From CoCoCore
\alias{makeCurrentCoCo} % From CoCoObjects
\alias{make.model} % From CoCoCore
\alias{my.assign} % From CoCoCore
\alias{quitCoCo} % From CoCoRaw

\description{Internal CoCoOldData and imported objects.}
\details{These are not to be called by the user.}
\keyword{internal}

\eof
\name{cutpoints}
\alias{cutpoints}

\title{ Reduce number of possible values for discrete variable }

\description{ Define cutpoints to transform a continuous variable
	      into a discrete variable in CoCo. 
	      The discrete variable must prior to the use of this
	      function be declared with the number of levels as
	      the cutpoints will result in.
	      }

\usage{
cutpoints(name, cutpoints, object = .current.coco)
}

\arguments{
  \item{name}{ A character string with the \code{name} of the variable. }
  \item{cutpoints}{ A vector of reals with the \code{cutpoints}. }
  \item{object}{ See \code{\link[CoCoRaw]{exportCoCo}}. }
}

% \details{ }

\value{ TRUE }

\references{ Badsberg, J.H.: A guide to CoCo, JSS, 2001
             ( http://www.jstatsoft.org/v06/i04/ )
             and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{ Jens Henrik Badsberg }

% \note{ ~~further notes~~ }

% \section{ToDo}{....}

\seealso{ \code{\link[CoCoRaw]{read.data}} and
	  \code{\link[CoCoRaw]{enterNames}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{read.data}
\alias{read.data}
\alias{read.specification}
\alias{read.names}
\alias{read.factors}
\alias{read.observations}
\alias{read.list}
\alias{read.table.coco}

\title{ Read data from files or standard input }

\description{ Read data from files or standard input. }

\usage{
read.data(setslot = TRUE, object = .current.coco)

read.specification(setslot = TRUE, object = .current.coco)

read.names(setslot = TRUE, object = .current.coco)

read.factors(setslot = TRUE, object = .current.coco)

read.observations(setslot = TRUE, object = .current.coco)

read.list(silent = FALSE, setslot = TRUE, object = .current.coco)

read.table.coco(silent = FALSE, setslot = TRUE, object = .current.coco)
}

\arguments{
  \item{silent}{ Logical, if \code{silent} then CoCo is more silent. }
  \item{setslot}{ See \code{\link[CoCoRaw]{enterNames}}. }
  \item{object}{ See \code{\link[CoCoRaw]{exportCoCo}}. }
}

% \details{ }

\value{ TRUE }

\references{ Badsberg, J.H.: A guide to CoCo, JSS, 2001
             ( http://www.jstatsoft.org/v06/i04/ )
             and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{ Jens Henrik Badsberg }

% \note{ ~~further notes~~ }

% \section{ToDo}{....}

\seealso{ \code{\link[CoCoRaw]{set.data.file}} and
	  \code{\link[CoCoRaw]{enterNames}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{read.q.table}
\alias{read.q.table}
\alias{read.q.list}

\title{ Read Q tables, structural zeros, from file }

\description{ Read Q table. }

\usage{
read.q.table(set, setslot = TRUE, object = .current.coco)

read.q.list(set, setslot = TRUE, object = .current.coco)
}

\arguments{
  \item{set}{ A character string with the names 
	      of the \code{set} of variables. }
  \item{setslot}{ See \code{\link[CoCoRaw]{enterNames}}. }
  \item{object}{ See \code{\link[CoCoRaw]{exportCoCo}}. }
}

% \details{ }

\value{ TRUE }

\references{ Badsberg, J.H.: A guide to CoCo, JSS, 2001
             ( http://www.jstatsoft.org/v06/i04/ )
             and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{ Jens Henrik Badsberg }

% \note{ ~~further notes~~ }

% \section{ToDo}{....}

\seealso{ \code{\link[CoCoRaw]{enterNames}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{redefine.factor}
\alias{redefine.factor}

\title{ Change the number of declared levels for a discrete variable }

\description{
  Redefine the number of levels for a variable.
}

\usage{
redefine.factor(name, levels, missing.levels = 0, object = .current.coco)
}

\arguments{
  \item{name}{ A character string with the \code{name} of the variable. }
  \item{levels}{ A integer with the new number of \code{levels}. }
  \item{missing.levels}{ A integer with the new number of
			 \code{missing.levels}. }
  \item{object}{ See \code{\link[CoCoRaw]{exportCoCo}}. }
}

% \details{ }

\value{ TRUE }

\references{ Badsberg, J.H.: A guide to CoCo, JSS, 2001
             ( http://www.jstatsoft.org/v06/i04/ )
             and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{ Jens Henrik Badsberg }

% \note{ ~~further notes~~ }

% \section{ToDo}{....}

\seealso{ \code{\link[CoCoRaw]{read.data}} and
	  \code{\link[CoCoRaw]{enterNames}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{reject.cases}
\alias{reject.cases}
\alias{select.cases}
\alias{or.reject.cases}
\alias{or.select.cases}

\title{ Declare a subset of the cases to be read }

\description{ Declare a subset of the cases to be read. }

\usage{
reject.cases(set, cell, object = .current.coco)

select.cases(set, cell, object = .current.coco)

or.reject.cases(set, cell, object = .current.coco)

or.select.cases(set, cell, object = .current.coco)
}

\arguments{
  \item{set}{ A character string with the names of the variables. }
  \item{cell}{ A numeric vector with the levels of the variables. }
  \item{object}{ See \code{\link[CoCoRaw]{exportCoCo}}. }
}

% \details{ }

\value{ TRUE }

\references{ Badsberg, J.H.: A guide to CoCo, JSS, 2001
             ( http://www.jstatsoft.org/v06/i04/ )
             and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{ Jens Henrik Badsberg }

% \note{ ~~further notes~~ }

% \section{ToDo}{....}

\seealso{ \code{\link[CoCoRaw]{read.data}} and
	  \code{\link[CoCoRaw]{enterNames}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{set.data.file}
\alias{set.data.file}
\alias{set.specification.file}
\alias{set.observations.file}

\title{ Declare files to read data from }

\description{ Assign data files. }

\usage{
set.data.file(file.name, object = .current.coco)

set.specification.file(file.name, object = .current.coco)

set.observations.file(file.name, object = .current.coco)
}

\arguments{
  \item{file.name}{ A character string with the \code{file.name}. }
  \item{object}{ See \code{\link[CoCoRaw]{exportCoCo}}. }
}

% \details{ }

\value{ TRUE }

\references{ Badsberg, J.H.: A guide to CoCo, JSS, 2001
             ( http://www.jstatsoft.org/v06/i04/ )
             and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{ Jens Henrik Badsberg }

% \note{ ~~further notes~~ }

% \section{ToDo}{....}

\seealso{ \code{\link[CoCoRaw]{read.data}} and
	  \code{\link[CoCoRaw]{enterNames}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{set.output}
\alias{set.output}

\title{ Set CoCo output file }

\description{ Write standard output from CoCo on file. }

\usage{
set.output(file.name, object = .current.coco)
}

\arguments{
  \item{file.name}{ A character string with the \code{file.name}. }
  \item{object}{ See \code{\link[CoCoRaw]{exportCoCo}}. }
}

% \details{ }

\value{ TRUE }

\references{ Badsberg, J.H.: A guide to CoCo, JSS, 2001
             ( http://www.jstatsoft.org/v06/i04/ )
             and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{ Jens Henrik Badsberg }

\note{ This command is fragile:
       Redirects the standard output,
       and causes R to crash under Windows. }

% \section{ToDo}{....}

% \seealso{ \code{\link[CoCoRaw]{enterNames}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{skip.missing}
\alias{skip.missing}

\title{ Declare that cases with missing values are skipped during reading }

\description{ Set CoCo to skip cases with any of the entered variables
	      with missing values.
	      The function has to be used between entering the specification
	      and entering the observations.
}

\usage{
skip.missing(object = .current.coco)
}

\arguments{
  \item{object}{ See \code{\link[CoCoRaw]{exportCoCo}}. }
}

% \details{ }

\value{ TRUE }

\references{ Badsberg, J.H.: A guide to CoCo, JSS, 2001
             ( http://www.jstatsoft.org/v06/i04/ )
             and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{ Jens Henrik Badsberg }

% \note{ ~~further notes~~ }

% \section{ToDo}{....}

\seealso{ \code{\link[CoCoRaw]{read.data}},
	  \code{\link[CoCoRaw]{enterNames}},
	  \code{\link[CoCoRaw]{enterList}},
	  \code{\link[CoCoRaw]{enterTable}}, and
	  \code{\link[CoCoRaw]{excludeMissing}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{source.coco}
\alias{source.coco}

\title{ Read CoCo commands from file }

\description{ Read coco commands. }

\usage{
source.coco(file.name, object = .current.coco)
}

\arguments{
  \item{file.name}{ A character string with the \code{file.name} 
		    of the file to read from. }
  \item{object}{ See \code{\link[CoCoRaw]{exportCoCo}}. }
}

% \details{ }

\value{ TRUE }

\references{ Badsberg, J.H.: A guide to CoCo, JSS, 2001
             ( http://www.jstatsoft.org/v06/i04/ )
             and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{ Jens Henrik Badsberg }

\note{ This command is fragile:
       Redirects the standard input,
       and causes R to crash under Windows. }

% \section{ToDo}{....}

\seealso{ \code{\link[CoCoRaw]{enterNames}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
